package com.gic.haoban.manage.web.controller.content;

import com.gic.api.base.commons.BasePageInfo;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.content.api.dto.column.ContentColumnListDTO;
import com.gic.content.api.dto.material.ContentMaterialFrontDTO;
import com.gic.content.api.dto.material.ContentMaterialShareInfoDTO;
import com.gic.content.api.qdto.material.ContentMaterialPageFrontQDTO;
import com.gic.content.api.qdto.material.ContentMaterialShareQDTO;
import com.gic.content.api.service.ContentColumnApiService;
import com.gic.content.api.service.ContentMaterialApiService;
import com.gic.content.api.service.ContentMaterialShareApiService;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.manage.web.qo.content.ContentMaterialQO;
import com.gic.haoban.manage.web.qo.content.ContentMaterialShareQO;
import com.gic.haoban.manage.web.vo.content.ContentColumnInfoVO;
import com.gic.haoban.manage.web.vo.content.ContentMaterialInfoVO;
import com.gic.haoban.manage.web.vo.content.ContentMaterialShareInfoVO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author MUSI
 * @Date 2022/11/14 6:06 PM
 * @Description
 * @Version
 **/
@RestController
public class ContentMaterialController {

    @Autowired
    private ContentColumnApiService contentColumnApiService;
    @Autowired
    private ContentMaterialApiService contentMaterialApiService;
    @Autowired
    private ContentMaterialShareApiService contentMaterialShareApiService;


    /**
     * 获取栏目筛选条件
     * @param enterpriseId
     * @return
     */
    @RequestMapping(path = "/column-list")
    public RestResponse<List<ContentColumnInfoVO>> queryContentColumn(String enterpriseId){
        ServiceResponse<List<ContentColumnListDTO>> serviceResponse = contentColumnApiService.listColumn(enterpriseId, 1);
        if (!serviceResponse.isSuccess() || CollectionUtils.isEmpty(serviceResponse.getResult())){
            return RestResponse.successResult(Collections.emptyList());
        }
        List<ContentColumnInfoVO> contentColumnInfos = EntityUtil.changeEntityListByJSON(ContentColumnInfoVO.class, serviceResponse.getResult());
        return RestResponse.successResult(contentColumnInfos);
    }


    /**
     *
     * 素材列表
     *
     * @return
     */
    @RequestMapping(path = "/content-material-list")
    public RestResponse<Page<ContentMaterialInfoVO>> queryContentMaterialList(@RequestBody ContentMaterialQO contentMaterialQO){

        ContentMaterialPageFrontQDTO contentMaterialPageFrontQDTO = new ContentMaterialPageFrontQDTO();
        contentMaterialPageFrontQDTO.setEnterpriseId(contentMaterialQO.getEnterpriseId());
        contentMaterialPageFrontQDTO.setKeyWord(contentMaterialQO.getSearch());
        contentMaterialPageFrontQDTO.setContentColumnId(contentMaterialQO.getContentColumnId());
        if (contentMaterialQO.getSortType() != null){
            if (contentMaterialQO.getSortType() == 2){
                contentMaterialPageFrontQDTO.setHotFlag(1);
            }else if (contentMaterialQO.getSortType() == 3){
                contentMaterialPageFrontQDTO.setMaterialType(4);
            }
        }
        BasePageInfo pageInfo = new BasePageInfo();
        pageInfo.setPageNum(contentMaterialQO.getPageNum());
        pageInfo.setPageSize(contentMaterialQO.getPageSize());
        ServiceResponse<Page<ContentMaterialFrontDTO>> serviceResponse = contentMaterialApiService.pageMaterialFront(contentMaterialPageFrontQDTO, pageInfo);
        if (!serviceResponse.isSuccess() || CollectionUtils.isEmpty(serviceResponse.getResult().getResult())){
            return RestResponse.successResult(new Page<>());
        }
        Page<ContentMaterialFrontDTO> responseResult = serviceResponse.getResult();
        Page<ContentMaterialInfoVO> result = new Page<>();
        result.setTotalCount(responseResult.getTotalCount());
        List<ContentMaterialInfoVO> contentMaterialInfos = responseResult.getResult().stream()
                .map(item -> {
                    ContentMaterialInfoVO contentMaterialInfoVO = new ContentMaterialInfoVO();
                    BeanUtils.copyProperties(item, contentMaterialInfoVO);
                    contentMaterialInfoVO.setPublishTime(item.getPublishBeginTime());
                    if (StringUtils.isNotBlank(item.getMaterialImageUrls())) {
                        String[] split = StringUtils.split(item.getMaterialImageUrls(), ",");
                        List<String> imageUrls = Arrays.stream(split).collect(Collectors.toList());
                        contentMaterialInfoVO.setMaterialImageUrls(imageUrls);
                    }
                    if (StringUtils.isNotBlank(item.getMaterialThumbnailImageUrls())) {
                        String[] split = StringUtils.split(item.getMaterialThumbnailImageUrls(), ",");
                        List<String> imageUrls = Arrays.stream(split).collect(Collectors.toList());
                        contentMaterialInfoVO.setMaterialThumbnailImageUrls(imageUrls);
                    }
                    return contentMaterialInfoVO;
                }).collect(Collectors.toList());
        result.setResult(contentMaterialInfos);
        return RestResponse.successResult(result);
    }

    /**
     * 分享商品素材
     * @param contentMaterialShareQO
     * @return
     */
    @RequestMapping(path = "/share-content-material")
    public RestResponse<ContentMaterialShareInfoVO> shareContentMaterial(ContentMaterialShareQO contentMaterialShareQO){

        
        if (StringUtils.isBlank(contentMaterialShareQO.getEnterpriseId())){
            return RestResponse.failure("-777", "企业参数异常");
        }
        if (StringUtils.isBlank(contentMaterialShareQO.getGoodsId())){
            // 无商品id 不生成参数
            return RestResponse.successResult();
        }
        ContentMaterialShareQDTO contentMaterialShareQDTO = new ContentMaterialShareQDTO();
        contentMaterialShareQDTO.setEnterpriseId(contentMaterialShareQO.getEnterpriseId());
        contentMaterialShareQDTO.setGoodsId(contentMaterialShareQO.getGoodsId());
        contentMaterialShareQDTO.setContentMaterialId(contentMaterialShareQO.getContentMaterialId());
        contentMaterialShareQDTO.setClerkId(contentMaterialShareQO.getClerkId());
        contentMaterialShareQDTO.setStoreId(contentMaterialShareQO.getStoreId());
        ServiceResponse<ContentMaterialShareInfoDTO> serviceResponse = contentMaterialShareApiService.shareContentMaterial(contentMaterialShareQDTO);
        if (!serviceResponse.isSuccess()){
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
        ContentMaterialShareInfoVO shareInfoVO = new ContentMaterialShareInfoVO();
        BeanUtils.copyProperties(serviceResponse.getResult(), shareInfoVO);
        return RestResponse.successResult(shareInfoVO);
    }

}
